# Reading and writing old-format PDB files

[![Documentation Status](https://readthedocs.org/projects/old-pdb/badge/?version=latest)](https://old-pdb.readthedocs.io/en/latest/?badge=latest)
[![pytest](https://github.com/Electrostatics/old_pdb/actions/workflows/pytest.yml/badge.svg)](https://github.com/Electrostatics/old_pdb/actions/workflows/pytest.yml)

This code reads and writes the [old PDB format](https://www.wwpdb.org/documentation/file-format-content/format33/v3.3.html).

See [the documentation](https://old-pdb.readthedocs.io/en/latest/?badge=latest) for more information.

Development of this code was greatly helped by [the Chimera documentation](https://www.cgl.ucsf.edu/chimera/docs/UsersGuide/tutorials/pdbintro.html).
